==> jc-1.4.0.tar.gz: org/dellroad/jc/JCFinder.h <==
// public class org.dellroad.jc.JCFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 753789d11b101440 org_dellroad_jc_JCFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_JCFinder_H_
#define _JC_org_dellroad_jc_JCFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_JCFinder$sub_refs	_jc_org_dellroad_jc_JCFinder$sub_refs;
typedef struct _jc_org_dellroad_jc_JCFinder$sub_nonrefs	_jc_org_dellroad_jc_JCFinder$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_JCFinder$refs	_jc_org_dellroad_jc_JCFinder$refs;
typedef struct _jc_org_dellroad_jc_JCFinder$nonrefs	_jc_org_dellroad_jc_JCFinder$nonrefs;
typedef struct _jc_org_dellroad_jc_JCFinder$object	_jc_org_dellroad_jc_JCFinder$object;

typedef const struct _jc_org_dellroad_jc_JCFinder$vmethods	_jc_org_dellroad_jc_JCFinder$vmethods;
typedef const struct _jc_org_dellroad_jc_JCFinder$vtable	_jc_org_dellroad_jc_JCFinder$vtable;
typedef const struct _jc_org_dellroad_jc_JCFinder$vtype	_jc_org_dellroad_jc_JCFinder$vtype;

// Constructors
extern void _jc_org_dellroad_jc_JCFinder$method$_init$2815ca8f2d550897(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern _jc_byte_array *_jc_org_dellroad_jc_JCFinder$method$getClassfile$2323c94e9ff74fa5(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *);
extern jlong _jc_org_dellroad_jc_JCFinder$method$getClassfileHash$c7c304d80ea40ac2(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_JCFinder$method_info$getClassfile$2323c94e9ff74fa5;
extern _jc_method _jc_org_dellroad_jc_JCFinder$method_info$getClassfileHash$c7c304d80ea40ac2;

// Static methods
extern _jc_byte_array *_jc_org_dellroad_jc_JCFinder$method$getClassfile$07a5d5462cd674f2(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);
extern jlong _jc_org_dellroad_jc_JCFinder$method$getClassfileHash$b8d183b80cc285dd(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods structure
struct _jc_org_dellroad_jc_JCFinder$vmethods {
	_jc_byte_array	*(*getClassfile$2323c94e9ff74fa5)(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *);
	jlong	(*getClassfileHash$c7c304d80ea40ac2)(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_org_dellroad_jc_JCFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_JCFinder$vmethods	org_dellroad_jc_JCFinder;
};

// Vtype
struct _jc_org_dellroad_jc_JCFinder$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_JCFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_JCFinder$sub_refs {
	struct _jc_java_lang_ClassLoader$object	*loader;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_JCFinder$refs {
    _jc_org_dellroad_jc_JCFinder$sub_refs	org_dellroad_jc_JCFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_JCFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_JCFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_JCFinder$sub_nonrefs	org_dellroad_jc_JCFinder;
};

// Object instance structure
struct _jc_org_dellroad_jc_JCFinder$object {
	_jc_org_dellroad_jc_JCFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_JCFinder$vtype	*vtype;
	_jc_org_dellroad_jc_JCFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_JCFinder$vtype _jc_org_dellroad_jc_JCFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_JCFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_JCFinder$class_object;

#endif	/* _JC_org_dellroad_jc_JCFinder_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/JCFinder.h <==
// public class org.dellroad.jc.JCFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 753789d11b101440 org_dellroad_jc_JCFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_JCFinder_H_
#define _JC_org_dellroad_jc_JCFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_JCFinder$sub_refs	_jc_org_dellroad_jc_JCFinder$sub_refs;
typedef struct _jc_org_dellroad_jc_JCFinder$sub_nonrefs	_jc_org_dellroad_jc_JCFinder$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_JCFinder$refs	_jc_org_dellroad_jc_JCFinder$refs;
typedef struct _jc_org_dellroad_jc_JCFinder$nonrefs	_jc_org_dellroad_jc_JCFinder$nonrefs;
typedef struct _jc_org_dellroad_jc_JCFinder$object	_jc_org_dellroad_jc_JCFinder$object;

typedef const struct _jc_org_dellroad_jc_JCFinder$vmethods	_jc_org_dellroad_jc_JCFinder$vmethods;
typedef const struct _jc_org_dellroad_jc_JCFinder$vtable	_jc_org_dellroad_jc_JCFinder$vtable;
typedef const struct _jc_org_dellroad_jc_JCFinder$vtype	_jc_org_dellroad_jc_JCFinder$vtype;

// Constructors
extern void _jc_org_dellroad_jc_JCFinder$method$_init$2815ca8f2d550897(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_byte_array *_jc_org_dellroad_jc_JCFinder$method$getClassfile$2323c94e9ff74fa5(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern jlong _jc_org_dellroad_jc_JCFinder$method$getClassfileHash$c7c304d80ea40ac2(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_JCFinder$method_info$getClassfile$2323c94e9ff74fa5;
extern _jc_method _jc_org_dellroad_jc_JCFinder$method_info$getClassfileHash$c7c304d80ea40ac2;

// Static methods
extern _jc_byte_array *_jc_org_dellroad_jc_JCFinder$method$getClassfile$07a5d5462cd674f2(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
extern jlong _jc_org_dellroad_jc_JCFinder$method$getClassfileHash$b8d183b80cc285dd(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_org_dellroad_jc_JCFinder$vmethods {
	_jc_byte_array	*(*getClassfile$2323c94e9ff74fa5)(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	jlong	(*getClassfileHash$c7c304d80ea40ac2)(_jc_env *, struct _jc_org_dellroad_jc_JCFinder$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_JCFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_JCFinder$vmethods	org_dellroad_jc_JCFinder;
};

// Vtype
struct _jc_org_dellroad_jc_JCFinder$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_JCFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_JCFinder$sub_refs {
	struct _jc_java_lang_ClassLoader$object	*loader;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_JCFinder$refs {
    _jc_org_dellroad_jc_JCFinder$sub_refs	org_dellroad_jc_JCFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_JCFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_JCFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_JCFinder$sub_nonrefs	org_dellroad_jc_JCFinder;
};

// Object instance structure
struct _jc_org_dellroad_jc_JCFinder$object {
	_jc_org_dellroad_jc_JCFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_JCFinder$vtype	*vtype;
	_jc_org_dellroad_jc_JCFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_JCFinder$vtype _jc_org_dellroad_jc_JCFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_JCFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_JCFinder$class_object;

#endif	/* _JC_org_dellroad_jc_JCFinder_H_ */
